import { prisma } from "../src/configs/prismaClient.js";
import faker from 'faker-br';
import bcrypt from 'bcryptjs';

async function clearDatabase() {
  try {
    await prisma.$executeRaw`SET FOREIGN_KEY_CHECKS = 0;`;
    await prisma.$executeRaw`TRUNCATE TABLE arquivos;`;
    await prisma.$executeRaw`TRUNCATE TABLE feito;`;
    await prisma.$executeRaw`TRUNCATE TABLE permissoes;`;
    await prisma.$executeRaw`TRUNCATE TABLE feito;`;
    await prisma.$executeRaw`TRUNCATE TABLE rota;`;
    await prisma.$executeRaw`TRUNCATE TABLE grupo;`;
    await prisma.$executeRaw`TRUNCATE TABLE usuario;`;
    await prisma.$executeRaw`TRUNCATE TABLE aluno;`;
    await prisma.$executeRaw`TRUNCATE TABLE aula;`;
    await prisma.$executeRaw`TRUNCATE TABLE modulo;`;
    await prisma.$executeRaw`TRUNCATE TABLE professor;`;
    await prisma.$executeRaw`TRUNCATE TABLE turma;`;
    await prisma.$executeRaw`SET FOREIGN_KEY_CHECKS = 1;`;
  } catch (error) {
    console.error('Erro ao limpar o banco de dados:', error);
  }
}

async function seedDatabase() {
  try {
    let SALT = parseInt(process.env.SALT);
    let salt = await bcrypt.genSalt(SALT);
    const senhaHash = await bcrypt.hash("senhatest", salt);
    const senhaComplexa = await bcrypt.hash("#senhaS2", salt);

    // Inserindo dados na tabela `grupo`
    const grupos = await prisma.grupo.createMany({
      data: [
        { nome: 'alunos' },
        { nome: 'professores' },
      ],
    });

    // Inserindo dados na tabela `rota`
    const rotas = await prisma.rota.createMany({
      data: [
        { rota: 'aula', get: true, post: false, patch: false, put: false, delete: false },
        { rota: 'modulo', get: true, post: false, patch: false, put: false, delete: false },
        { rota: 'turma', get: true, post: false, patch: false, put: false, delete: false },
        { rota: 'usuario', get: true, post: false, patch: false, put: false, delete: false },

        { rota: 'aula/status', get: false, post: true, patch: false, put: false, delete: false },

        { rota: 'usuario/csv', get: false, post: true, patch: false, put: false, delete: false },
        { rota: 'aula', get: true, post: true, patch: true, put: true, delete: true },
        { rota: 'modulo', get: true, post: true, patch: true, put: true, delete: true },
        { rota: 'turma', get: true, post: true, patch: true, put: true, delete: true },
        { rota: 'usuario', get: true, post: true, patch: true, put: true, delete: true },
        { rota: 'arquivos', get: true, post: true, patch: true, put: true, delete: true },
        { rota: 'arquivos/*', get: true, post: true, patch: true, put: true, delete: true },
        { rota: 'arquivos:id', get: true, post: true, patch: true, put: true, delete: true },

        { rota: 'arquivos', get: true, post: false, patch: false, put: false, delete: false },
        { rota: 'arquivos/*', get: true, post: false, patch: false, put: false, delete: false },
        { rota: 'arquivos:id', get: true, post: false, patch: false, put: false, delete: false },
      ],
    });

    // Inserindo permissões
    const permissoes = await prisma.permissoes.createMany({
      data: [
        { rota_id: 1, grupo_id: 1 }, // alunos - aula
        { rota_id: 2, grupo_id: 1 }, // alunos - modulo
        { rota_id: 3, grupo_id: 1 }, // alunos - turma
        { rota_id: 4, grupo_id: 1 }, // alunos - usuario
        { rota_id: 5, grupo_id: 1 }, // alunos - aula/status
        { rota_id: 14, grupo_id: 1 }, // alunos - turma
        { rota_id: 15, grupo_id: 1 }, // alunos - usuario
        { rota_id: 16, grupo_id: 1 }, // alunos - aula/status

        { rota_id: 5, grupo_id: 2 }, // alunos - aula/status
        { rota_id: 6, grupo_id: 2 }, // professores - aula
        { rota_id: 7, grupo_id: 2 }, // professores - modulo
        { rota_id: 8, grupo_id: 2 }, // professores - turma
        { rota_id: 9, grupo_id: 2 }, // professores - usuario
        { rota_id: 10, grupo_id: 2 }, // professores - usuario
        { rota_id: 11, grupo_id: 2 }, // professores - usuario
        { rota_id: 12, grupo_id: 2 }, // professores - usuario
        { rota_id: 13, grupo_id: 2 }, // professores - usuario
      ],
    });

    // Inserindo dados na tabela `usuario`
    const usuarios = await prisma.usuario.createMany({
      data: [
        { nome: "professor", grupo_id: 2, senha: senhaHash, matricula: "123456", active: true, refresh_token: null },
        { nome: "professor2", grupo_id: 2, senha: senhaComplexa, matricula: "1020304050", active: true, refresh_token: null },
        { nome: faker.name.findName(), grupo_id: 1, senha: senhaHash, matricula: "123457", active: false, refresh_token: null },
        { nome: faker.name.findName(), grupo_id: 1, senha: senhaHash, matricula: "123458", active: true, refresh_token: null },
        { nome: faker.name.findName(), grupo_id: 1, senha: senhaHash, matricula: "123459", active: true , refresh_token: null},
        { nome: faker.name.findName(), grupo_id: 1, senha: senhaHash, matricula: "123461", active: true , refresh_token: null},
        { nome: faker.name.findName(), grupo_id: 1, senha: senhaHash, matricula: "34663467", active: false , refresh_token: null},
        { nome: faker.name.findName(), grupo_id: 1, senha: senhaHash, matricula: "34264646", active: true , refresh_token: null},
        { nome: faker.name.findName(), grupo_id: 1, senha: senhaHash, matricula: "64633734", active: true , refresh_token: null},
        { nome: faker.name.findName(), grupo_id: 1, senha: senhaHash, matricula: "23646364", active: true , refresh_token: null},
        { nome: faker.name.findName(), grupo_id: 1, senha: senhaHash, matricula: "75784833", active: false , refresh_token: null},
        { nome: faker.name.findName(), grupo_id: 1, senha: senhaHash, matricula: "35734678", active: true , refresh_token: null},
        { nome: faker.name.findName(), grupo_id: 1, senha: senhaHash, matricula: "37734733", active: true , refresh_token: null},
        { nome: faker.name.findName(), grupo_id: 1, senha: senhaHash, matricula: "64637866", active: true , refresh_token: null},
      ],
    });

    // Inserindo dados na tabela `turma`
    const turmas = await prisma.turma.createMany({
      data: [
        { nome: '1º Ano' },
        { nome: '2º Ano' },
        { nome: '3º Ano' },
        { nome: 'Graduação' },
      ],
    });

    // Inserindo dados na tabela `aluno`
    const alunos = await prisma.aluno.createMany({
      data: [
        { usuario_id: 2, turma_id: 1 },
        { usuario_id: 2, turma_id: 2 },
        { usuario_id: 2, turma_id: 3 },
        { usuario_id: 3, turma_id: 1 },
        { usuario_id: 3, turma_id: 2 },
        { usuario_id: 3, turma_id: 3 },
        { usuario_id: 4, turma_id: 1 },
        { usuario_id: 4, turma_id: 2 },
        { usuario_id: 4, turma_id: 3 },
        { usuario_id: 5, turma_id: 1 },
        { usuario_id: 5, turma_id: 2 },
        { usuario_id: 5, turma_id: 4 },
        { usuario_id: 6, turma_id: 4 },
      ],
    });

    // Inserindo dados na tabela `modulo`
    const modulos = await prisma.modulo.createMany({
      data: [
        { turma_id: 1, titulo: 'Introdução à Aritmética', descricao: 'Aprenda as operações básicas de adição, subtração, multiplicação e divisão.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image1.png" },
        { turma_id: 1, titulo: 'Frações e Decimais', descricao: 'Compreenda frações, números decimais e suas conversões.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image2.png" },
        { turma_id: 2, titulo: 'Geometria Básica', descricao: 'Estude figuras geométricas, perímetro e área.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image6.png" },
        { turma_id: 2, titulo: 'Equações Algébricas', descricao: 'Resolva equações do 1º e 2º grau com facilidade.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image3.png" },
        { turma_id: 3, titulo: 'Trigonometria', descricao: 'Explore razões trigonométricas e o círculo unitário.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image4.png" },
        { turma_id: 3, titulo: 'Estatística e Probabilidade', descricao: 'Introdução a média, mediana, moda e cálculo de probabilidades.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image5.png" },
        { turma_id: 4, titulo: 'Estatística e Probabilidade Avançado', descricao: 'Introdução a média, mediana, moda e cálculo de probabilidades.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image3.png" },
        { turma_id: 1, titulo: 'Números Complexos', descricao: 'Aprenda sobre a unidade imaginária e operações com números complexos.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image1.png" },
        { turma_id: 1, titulo: 'Funções Exponenciais', descricao: 'Explore o comportamento das funções exponenciais e suas aplicações.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image5.png" },
        { turma_id: 2, titulo: 'Funções Logarítmicas', descricao: 'Entenda logaritmos e suas propriedades essenciais.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image3.png" },
        { turma_id: 2, titulo: 'Matrizes e Determinantes', descricao: 'Estude operações com matrizes e o cálculo de determinantes.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image4.png" },
        { turma_id: 3, titulo: 'Sistemas Lineares', descricao: 'Aprenda a resolver sistemas de equações lineares usando matrizes.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image5.png" },
        { turma_id: 3, titulo: 'Derivadas e Aplicações', descricao: 'Introdução ao cálculo diferencial e suas aplicações.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image2.png" },
        { turma_id: 4, titulo: 'Integrais e Aplicações', descricao: 'Compreenda a integração e sua relação com áreas e volumes.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image4.png" },
        { turma_id: 4, titulo: 'Progressões Aritméticas e Geométricas', descricao: 'Explore sequências numéricas e suas propriedades.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image5.png" },
        { turma_id: 2, titulo: 'Teorema de Pitágoras e Aplicações', descricao: 'Aprofunde-se nas relações métricas dos triângulos retângulos.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image1.png" },
        { turma_id: 4, titulo: 'Números Primos e Criptografia', descricao: 'Descubra como os números primos são usados na segurança digital.', image: "https://plataforma-matematica-api.app.fslab.dev/imagens/image4.png" },
    ],    
    });

    // Inserindo dados na tabela `aula`
    const aulas = await prisma.aula.createMany({
      data: [
        {
          "modulo_id": 2,
          "titulo": "Introdução à Álgebra: Conceitos Básicos",
          "video": "https://www.youtube.com/watch?v=0UGJRHq2PS4&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=1",
          "descricao": "Nesta aula, abordaremos os conceitos iniciais fundamentais da álgebra, uma das áreas mais importantes da matemática. A álgebra lida com símbolos e as regras para manipulação desses símbolos, permitindo resolver uma ampla gama de problemas matemáticos. Começaremos com os conceitos de variáveis, constantes e expressões algébricas. Além disso, explicaremos como essas ferramentas podem ser utilizadas para resolver equações e entender as relações entre diferentes valores. A compreensão desses conceitos é essencial para avançar em outras disciplinas matemáticas, como geometria, cálculo e aritmética, e também serve de base para o aprendizado em física, economia e outras áreas científicas. A aula incluirá exemplos práticos de resolução de equações simples para aplicar o que foi aprendido."
        },
        {
          "modulo_id": 2,
          "titulo": "Equações de 1º Grau: Resolução e Aplicações",
          "video": "https://www.youtube.com/watch?v=0UGJRHq2PS4&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=2",
          "descricao": "Nesta aula, iremos estudar as equações de primeiro grau, que são aquelas que envolvem uma variável elevada à primeira potência. Vamos aprender a identificar uma equação do primeiro grau, compreender seus componentes e os diferentes métodos para resolvê-las, como adição, subtração, multiplicação e divisão de termos. Além disso, discutiremos a aplicação dessas equações em diversos contextos práticos, como no cálculo de valores desconhecidos em situações financeiras, no ajuste de preços e na previsão de custos em negócios. Serão apresentados exemplos reais e explicações sobre como utilizar essas ferramentas de forma eficiente em problemas do cotidiano."
        },
        {
          "modulo_id": 2,
          "titulo": "Funções Lineares: Entendendo o Conceito",
          "video": "https://www.youtube.com/watch?v=BhDm2qGy780&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=3",
          "descricao": "Nesta aula, vamos nos aprofundar no conceito de funções lineares, que têm a forma matemática y = mx + b, onde m é o coeficiente angular e b é o coeficiente linear. Vamos entender como as variações nos valores de m e b afetam o gráfico dessa função, além de aprender a interpretar e a representar essa função em um plano cartesiano. Exploraremos, também, aplicações práticas das funções lineares em contextos do mundo real, como a determinação de preços, a análise de custos e a modelagem de descontos progressivos em promoções. Compreender as funções lineares é essencial para avançar em temas mais complexos de álgebra e cálculo."
        },
        {
          "modulo_id": 2,
          "titulo": "Geometria Plana: Áreas e Perímetros de Figuras Planas",
          "video": "https://www.youtube.com/watch?v=YJyY6A_MOQc&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=4",
          "descricao": "A geometria plana é uma das disciplinas mais práticas da matemática, lidando com figuras em duas dimensões. Nesta aula, vamos estudar como calcular as áreas e os perímetros de diversas figuras geométricas, como quadrados, retângulos, triângulos, círculos, entre outras formas. Vamos aplicar as fórmulas matemáticas necessárias para realizar esses cálculos e entender como essas medições são essenciais em situações cotidianas. Por exemplo, essas habilidades podem ser úteis em projetos de construção, na confecção de embalagens, no planejamento de jardins e até em decisões financeiras, como o cálculo de custos de materiais em reformas ou construções."
        },
        {
          "modulo_id": 2,
          "titulo": "Teorema de Pitágoras: Aplicações em Triângulos Retângulos",
          "video": "https://www.youtube.com/watch?v=SgJpB78R7x0&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=5",
          "descricao": "O Teorema de Pitágoras é uma das leis mais importantes da geometria, utilizado para encontrar a medida de um lado de um triângulo retângulo quando se conhece os outros dois lados. O teorema afirma que o quadrado da hipotenusa (o lado oposto ao ângulo reto) é igual à soma dos quadrados dos catetos. Nesta aula, vamos explorar como aplicar essa fórmula para resolver problemas geométricos e práticos. Veremos, também, diversas maneiras de aplicar o Teorema de Pitágoras em situações cotidianas, como no planejamento de construções, na navegação e até no design de circuitos elétricos e sistemas de comunicação, mostrando sua relevância em várias áreas do conhecimento."
        },
        {
          "modulo_id": 2,
          "titulo": "Progressões Aritméticas: Definição e Exemplos",
          "video": "https://www.youtube.com/watch?v=4Vfw1XiHTpM&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=6",
          "descricao": "As progressões aritméticas (PA) são sequências numéricas em que cada termo após o primeiro é obtido pela soma de um valor constante. Nesta aula, vamos explorar como identificar uma PA, como calcular seu valor geral e também o valor do n-ésimo termo dessa sequência. Vamos abordar exemplos práticos e aprender a utilizar a fórmula da soma dos termos de uma PA. Compreender as progressões aritméticas é fundamental para resolver problemas do cotidiano, como o cálculo de juros simples, planejamento financeiro, organização de pagamentos mensais e até mesmo o ajuste de saldos em contas bancárias."
        },
        {
          "modulo_id": 2,
          "titulo": "Equações Quadráticas: Resolução e Gráficos",
          "video": "https://www.youtube.com/watch?v=QmIjZgKhAEo&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=7",
          "descricao": "As equações quadráticas são aquelas em que a variável está elevada ao quadrado. Nesta aula, vamos aprender a resolver equações quadráticas usando diferentes métodos, como fatoração, a fórmula de Bhaskara e o método de completar o quadrado. Também discutiremos a importância do gráfico dessas equações, que forma uma parábola no plano cartesiano, e como representar graficamente as soluções dessas equações. A compreensão das equações quadráticas é essencial em várias áreas da matemática e suas aplicações, como em problemas de física, economia e até na engenharia, onde o comportamento de sistemas é modelado por essas equações."
        },
        {
          "modulo_id": 2,
          "titulo": "Geometria Espacial: Volume de Sólidos",
          "video": "https://www.youtube.com/watch?v=04nnroZrmgg&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=8",
          "descricao": "Na geometria espacial, estudamos figuras tridimensionais, como cubos, esferas, cilindros e pirâmides. Nesta aula, vamos aprender a calcular o volume desses sólidos utilizando fórmulas específicas para cada tipo de figura. Veremos como calcular o volume de um cilindro, uma esfera, um cubo e outras formas tridimensionais, além de discutir como esses cálculos são usados no mundo real. Esses conceitos são aplicados em diversos campos, como em cálculos de capacidade de recipientes, no design e fabricação de produtos, e até em projetos de construção civil e arquitetura."
        },
        {
          "modulo_id": 2,
          "titulo": "Funções Quadráticas: Características e Gráficos",
          "video": "https://www.youtube.com/watch?v=_3YQvVKbqn0&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=9",
          "descricao": "As funções quadráticas são representadas por equações do tipo f(x) = ax² + bx + c, onde a, b e c são constantes. Nesta aula, vamos explorar as principais características dessas funções, como o vértice da parábola, a concavidade, as raízes e a simetria. Também veremos como o gráfico de uma função quadrática é uma parábola e como representá-la de forma precisa. Além disso, discutiremos aplicações das funções quadráticas, como na modelagem de movimentos de projéteis, no estudo de fenômenos naturais e em cálculos financeiros relacionados a investimentos e crescimento."
        },
        {
          "modulo_id": 2,
          "titulo": "Progressões Geométricas: Definição e Aplicações",
          "video": "https://www.youtube.com/watch?v=3amBZupsIdc&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=10",
          "descricao": "As progressões geométricas (PG) são sequências numéricas em que cada termo é obtido multiplicando o termo anterior por uma constante chamada razão. Nesta aula, vamos aprender a identificar uma progressão geométrica, calcular o n-ésimo termo e também entender como calcular a soma dos termos de uma PG. Além disso, exploraremos as aplicações práticas das progressões geométricas, especialmente em situações financeiras, como no cálculo de juros compostos, investimentos a longo prazo e outros cenários em que os valores aumentam ou diminuem exponencialmente."
        },
        {
          "modulo_id": 2,
          "titulo": "Trigonometria: Seno, Cosseno e Tangente",
          "video": "https://www.youtube.com/watch?v=Jf0sA3wBqXE&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=11",
          "descricao": "A trigonometria é uma parte fundamental da matemática, especialmente para o estudo de triângulos e suas propriedades. Nesta aula, vamos aprender sobre as três funções trigonométricas básicas: seno, cosseno e tangente, focando em como calcular esses valores em triângulos retângulos. Além disso, discutiremos as aplicações práticas da trigonometria em diversas áreas, como na física, na engenharia, na navegação e até em áreas como a arquitetura e a medicina, mostrando a importância dessa área da matemática para a resolução de problemas complexos e a análise de fenômenos do mundo real."
        },
        {
          "modulo_id": 2,
          "titulo": "Cálculo Diferencial: Derivadas e Suas Aplicações",
          "video": "https://www.youtube.com/watch?v=GPTxrh_mhow&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=12",
          "descricao": "O cálculo diferencial é uma das áreas mais essenciais da matemática moderna. Nesta aula, vamos aprender o conceito de derivada, que descreve a taxa de variação de uma função em relação a uma variável. Vamos entender como calcular derivadas e explorar como elas são aplicadas na resolução de problemas do mundo real, como otimização de lucros e minimização de custos em empresas, além de sua utilização em modelagem de fenômenos naturais, como a velocidade de partículas e o crescimento populacional. Compreender as derivadas é crucial para quem deseja aprofundar seus estudos em cálculo e em diversas áreas da ciência e da engenharia."
        },
        {
          modulo_id: 2,
          titulo: 'Introdução à Álgebra: Conceitos Básicos',
          video: "https://www.youtube.com/watch?v=Tu08PYjt-2Q&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=14",
          descricao: 'Nesta aula, vamos abordar os conceitos iniciais de álgebra. A álgebra é a área da matemática que lida com símbolos e as regras para manipulação desses símbolos. Começaremos explicando o que são variáveis, constantes, expressões algébricas e como utilizar essas ferramentas para resolver problemas matemáticos. A compreensão desses conceitos é fundamental para avançar nas aulas de álgebra e em outras áreas da matemática, como a geometria e a aritmética. Vamos praticar resolver equações simples e entender a lógica por trás das operações algébricas.'
        },
        {
          modulo_id: 2,
          titulo: 'Equações de 1º Grau: Resolução e Aplicações',
          video: "https://www.youtube.com/watch?v=GPTxrh_mhow&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=12",
          descricao: 'Nesta aula, vamos estudar as equações de primeiro grau, que são aquelas que envolvem uma variável elevada à primeira potência. Vamos aprender a identificar uma equação do primeiro grau e os métodos para resolvê-las, como a adição e subtração de termos, a multiplicação e divisão de ambos os lados da equação. Também veremos exemplos práticos de como aplicar essas equações na resolução de problemas cotidianos, como o cálculo de valores desconhecidos em situações financeiras e de negócios.'
        },
        {
          modulo_id: 2,
          titulo: 'Funções Lineares: Entendendo o Conceito',
          video: "https://www.youtube.com/watch?v=Tu08PYjt-2Q&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=14",
          descricao: 'Nesta aula, vamos explorar o conceito de funções lineares. Funções lineares são aquelas que têm a forma y = mx + b, onde m é o coeficiente angular e b é o coeficiente linear. Vamos entender como a mudança nos valores de m e b altera o gráfico da função e como representar essa função em um plano cartesiano. Além disso, discutiremos algumas aplicações práticas das funções lineares, como a determinação do custo de produção de um item em uma fábrica ou o cálculo de descontos progressivos em promoções.'
        },
        {
          modulo_id: 2,
          titulo: 'Geometria Plana: Áreas e Perímetros de Figuras Planas',
          video: "https://www.youtube.com/watch?v=GPTxrh_mhow&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=12",
          descricao: 'A geometria plana é uma parte importante da matemática, que lida com figuras em duas dimensões. Nesta aula, vamos estudar como calcular as áreas e os perímetros de figuras geométricas, como quadrados, retângulos, triângulos, círculos e outras formas. Vamos aprender a usar as fórmulas matemáticas para calcular essas medidas e entender como elas são úteis em diversas situações cotidianas, como no planejamento de um jardim, na construção de uma casa ou no cálculo de materiais necessários para confeccionar uma embalagem.'
        },
        {
          modulo_id: 2,
          titulo: 'Teorema de Pitágoras: Aplicações em Triângulos Retângulos',
          video: "https://www.youtube.com/watch?v=Tu08PYjt-2Q&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=14",
          descricao: 'O Teorema de Pitágoras é uma das leis mais fundamentais da geometria. Nesta aula, vamos estudar o teorema que afirma que, em um triângulo retângulo, o quadrado da hipotenusa é igual à soma dos quadrados dos catetos. Vamos aprender a aplicar essa fórmula para calcular o comprimento de um dos lados de um triângulo retângulo, dado os outros dois. Também vamos explorar as muitas maneiras de aplicar o Teorema de Pitágoras no mundo real, como em projetos de construção, na navegação e no design de circuitos elétricos.'
        },
        {
          modulo_id: 2,
          titulo: 'Progressões Aritméticas: Definição e Exemplos',
          video: "https://www.youtube.com/watch?v=YEaQDJeADTg&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=18",
          descricao: 'As progressões aritméticas (PA) são sequências numéricas em que cada termo após o primeiro é obtido pela soma de um valor constante. Nesta aula, vamos entender como identificar uma progressão aritmética, como calcular seu valor geral e o valor do n-ésimo termo. Vamos praticar com exemplos diversos e aprender a utilizar a fórmula da soma dos termos de uma PA. Essa compreensão é útil para resolver problemas do dia a dia, como o cálculo de juros simples e o planejamento de pagamentos de parcelas mensais.'
        },
        {
          modulo_id: 2,
          titulo: 'Equações Quadráticas: Resolução e Gráficos',
          video: "https://www.youtube.com/watch?v=6YnChMLDcos&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=19",
          descricao: 'As equações quadráticas são aquelas em que a variável está elevada ao quadrado. Nesta aula, vamos aprender a resolver equações quadráticas utilizando o método da fatoração, a fórmula de Bhaskara e o método de completar o quadrado. Além disso, vamos estudar como representar as soluções de uma equação quadrática graficamente, em um plano cartesiano, como uma parábola. A resolução de equações quadráticas é essencial para entender diversas áreas da matemática, como a física e a economia.'
        },
        {
          modulo_id: 2,
          titulo: 'Geometria Espacial: Volume de Sólidos',
          video: "https://www.youtube.com/watch?v=YEaQDJeADTg&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=18",
          descricao: 'Na geometria espacial, estudamos figuras tridimensionais, como cubos, esferas, cilindros e pirâmides. Nesta aula, vamos aprender a calcular o volume desses sólidos utilizando fórmulas específicas. Vamos ver como calcular o volume de um cilindro, uma esfera e um cubo, e também entender como esses cálculos são aplicados no mundo real, como no cálculo de quantidade de materiais necessários para fabricar objetos ou calcular a capacidade de recipientes e reservatórios.'
        },
        {
          modulo_id: 2,
          titulo: 'Funções Quadráticas: Características e Gráficos',
          video: "https://www.youtube.com/watch?v=6YnChMLDcos&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=19",
          descricao: 'As funções quadráticas são representadas por equações do tipo f(x) = ax² + bx + c, onde a, b e c são constantes. Nesta aula, vamos aprender as propriedades dessas funções, como o vértice, a concavidade e as raízes. Vamos também explorar o gráfico de uma função quadrática, que é uma parábola. Além disso, estudaremos como as funções quadráticas são usadas em várias áreas, como na modelagem de movimentos de projéteis e no estudo de fenômenos naturais.'
        },
        {
          modulo_id: 2,
          titulo: 'Progressões Geométricas: Definição e Aplicações',
          video: "https://www.youtube.com/watch?v=YEaQDJeADTg&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=18",
          descricao: 'As progressões geométricas (PG) são sequências numéricas em que cada termo é obtido multiplicando o anterior por uma constante chamada razão. Nesta aula, vamos aprender a identificar uma progressão geométrica e a calcular o n-ésimo termo de uma PG. Também veremos como calcular a soma dos termos de uma progressão geométrica e as aplicações dessa sequência em situações financeiras, como no cálculo de juros compostos.'
        },
        {
          modulo_id: 2,
          titulo: 'Trigonometria: Seno, Cosseno e Tangente',
          video: "https://www.youtube.com/watch?v=6YnChMLDcos&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=19",
          descricao: 'A trigonometria é uma área da matemática que estuda as relações entre os lados e os ângulos de um triângulo. Nesta aula, vamos focar em três funções trigonométricas básicas: seno, cosseno e tangente. Vamos aprender como calcular essas funções em um triângulo retângulo e entender suas aplicações práticas em áreas como a física, a engenharia e a navegação. A compreensão dessas funções é essencial para a resolução de muitos problemas matemáticos complexos.'
        },
        {
          modulo_id: 2,
          titulo: 'Cálculo Diferencial: Derivadas e Suas Aplicações',
          video: "https://www.youtube.com/watch?v=N27xZJj1m-4&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=30",
          descricao: 'O cálculo diferencial é uma das áreas mais importantes da matemática moderna. Nesta aula, vamos aprender o conceito de derivada, que mede a taxa de variação de uma função. Vamos entender como calcular derivadas e explorar as aplicações desse conceito em problemas de otimização, como maximizar lucros ou minimizar custos, e na modelagem de fenômenos naturais, como o movimento de partículas ou a taxa de crescimento de populações.'
        },
        {
          "modulo_id": 1,
          "titulo": "Introdução à Álgebra: Conceitos Básicos",
          "video": "https://www.youtube.com/watch?v=e78_5WIssSU&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB",
          "descricao": "Nesta aula, abordaremos os conceitos iniciais fundamentais da álgebra, uma das áreas mais importantes da matemática. A álgebra lida com símbolos e as regras para manipulação desses símbolos, permitindo resolver uma ampla gama de problemas matemáticos. Começaremos com os conceitos de variáveis, constantes e expressões algébricas. Além disso, explicaremos como essas ferramentas podem ser utilizadas para resolver equações e entender as relações entre diferentes valores. A compreensão desses conceitos é essencial para avançar em outras disciplinas matemáticas, como geometria, cálculo e aritmética, e também serve de base para o aprendizado em física, economia e outras áreas científicas. A aula incluirá exemplos práticos de resolução de equações simples para aplicar o que foi aprendido."
        },
        {
          "modulo_id": 1,
          "titulo": "Equações de 1º Grau: Resolução e Aplicações",
          "video": "https://www.youtube.com/watch?v=0UGJRHq2PS4&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=2",
          "descricao": "Nesta aula, iremos estudar as equações de primeiro grau, que são aquelas que envolvem uma variável elevada à primeira potência. Vamos aprender a identificar uma equação do primeiro grau, compreender seus componentes e os diferentes métodos para resolvê-las, como adição, subtração, multiplicação e divisão de termos. Além disso, discutiremos a aplicação dessas equações em diversos contextos práticos, como no cálculo de valores desconhecidos em situações financeiras, no ajuste de preços e na previsão de custos em negócios. Serão apresentados exemplos reais e explicações sobre como utilizar essas ferramentas de forma eficiente em problemas do cotidiano."
        },
        {
          "modulo_id": 3,
          "titulo": "Funções Lineares: Entendendo o Conceito",
          "video": "https://www.youtube.com/watch?v=BhDm2qGy780&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=3",
          "descricao": "Nesta aula, vamos nos aprofundar no conceito de funções lineares, que têm a forma matemática y = mx + b, onde m é o coeficiente angular e b é o coeficiente linear. Vamos entender como as variações nos valores de m e b afetam o gráfico dessa função, além de aprender a interpretar e a representar essa função em um plano cartesiano. Exploraremos, também, aplicações práticas das funções lineares em contextos do mundo real, como a determinação de preços, a análise de custos e a modelagem de descontos progressivos em promoções. Compreender as funções lineares é essencial para avançar em temas mais complexos de álgebra e cálculo."
        },
        {
          "modulo_id": 3,
          "titulo": "Geometria Plana: Áreas e Perímetros de Figuras Planas",
          "video": "https://www.youtube.com/watch?v=YJyY6A_MOQc&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=4",
          "descricao": "A geometria plana é uma das disciplinas mais práticas da matemática, lidando com figuras em duas dimensões. Nesta aula, vamos estudar como calcular as áreas e os perímetros de diversas figuras geométricas, como quadrados, retângulos, triângulos, círculos, entre outras formas. Vamos aplicar as fórmulas matemáticas necessárias para realizar esses cálculos e entender como essas medições são essenciais em situações cotidianas. Por exemplo, essas habilidades podem ser úteis em projetos de construção, na confecção de embalagens, no planejamento de jardins e até em decisões financeiras, como o cálculo de custos de materiais em reformas ou construções."
        },
        {
          "modulo_id": 4,
          "titulo": "Teorema de Pitágoras: Aplicações em Triângulos Retângulos",
          "video": "https://www.youtube.com/watch?v=SgJpB78R7x0&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=5",
          "descricao": "O Teorema de Pitágoras é uma das leis mais importantes da geometria, utilizado para encontrar a medida de um lado de um triângulo retângulo quando se conhece os outros dois lados. O teorema afirma que o quadrado da hipotenusa (o lado oposto ao ângulo reto) é igual à soma dos quadrados dos catetos. Nesta aula, vamos explorar como aplicar essa fórmula para resolver problemas geométricos e práticos. Veremos, também, diversas maneiras de aplicar o Teorema de Pitágoras em situações cotidianas, como no planejamento de construções, na navegação e até no design de circuitos elétricos e sistemas de comunicação, mostrando sua relevância em várias áreas do conhecimento."
        },
        {
          "modulo_id": 4,
          "titulo": "Progressões Aritméticas: Definição e Exemplos",
          "video": "https://www.youtube.com/watch?v=4Vfw1XiHTpM&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=6",
          "descricao": "As progressões aritméticas (PA) são sequências numéricas em que cada termo após o primeiro é obtido pela soma de um valor constante. Nesta aula, vamos explorar como identificar uma PA, como calcular seu valor geral e também o valor do n-ésimo termo dessa sequência. Vamos abordar exemplos práticos e aprender a utilizar a fórmula da soma dos termos de uma PA. Compreender as progressões aritméticas é fundamental para resolver problemas do cotidiano, como o cálculo de juros simples, planejamento financeiro, organização de pagamentos mensais e até mesmo o ajuste de saldos em contas bancárias."
        },
        {
          "modulo_id": 5,
          "titulo": "Equações Quadráticas: Resolução e Gráficos",
          "video": "https://www.youtube.com/watch?v=QmIjZgKhAEo&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=7",
          "descricao": "As equações quadráticas são aquelas em que a variável está elevada ao quadrado. Nesta aula, vamos aprender a resolver equações quadráticas usando diferentes métodos, como fatoração, a fórmula de Bhaskara e o método de completar o quadrado. Também discutiremos a importância do gráfico dessas equações, que forma uma parábola no plano cartesiano, e como representar graficamente as soluções dessas equações. A compreensão das equações quadráticas é essencial em várias áreas da matemática e suas aplicações, como em problemas de física, economia e até na engenharia, onde o comportamento de sistemas é modelado por essas equações."
        },
        {
          "modulo_id": 5,
          "titulo": "Geometria Espacial: Volume de Sólidos",
          "video": "https://www.youtube.com/watch?v=04nnroZrmgg&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=8",
          "descricao": "Na geometria espacial, estudamos figuras tridimensionais, como cubos, esferas, cilindros e pirâmides. Nesta aula, vamos aprender a calcular o volume desses sólidos utilizando fórmulas específicas para cada tipo de figura. Veremos como calcular o volume de um cilindro, uma esfera, um cubo e outras formas tridimensionais, além de discutir como esses cálculos são usados no mundo real. Esses conceitos são aplicados em diversos campos, como em cálculos de capacidade de recipientes, no design e fabricação de produtos, e até em projetos de construção civil e arquitetura."
        },
        {
          "modulo_id": 1,
          "titulo": "Funções Quadráticas: Características e Gráficos",
          "video": "https://www.youtube.com/watch?v=_3YQvVKbqn0&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=9",
          "descricao": "As funções quadráticas são representadas por equações do tipo f(x) = ax² + bx + c, onde a, b e c são constantes. Nesta aula, vamos explorar as principais características dessas funções, como o vértice da parábola, a concavidade, as raízes e a simetria. Também veremos como o gráfico de uma função quadrática é uma parábola e como representá-la de forma precisa. Além disso, discutiremos aplicações das funções quadráticas, como na modelagem de movimentos de projéteis, no estudo de fenômenos naturais e em cálculos financeiros relacionados a investimentos e crescimento."
        },
        {
          "modulo_id": 3,
          "titulo": "Progressões Geométricas: Definição e Aplicações",
          "video": "https://www.youtube.com/watch?v=3amBZupsIdc&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=10",
          "descricao": "As progressões geométricas (PG) são sequências numéricas em que cada termo é obtido multiplicando o termo anterior por uma constante chamada razão. Nesta aula, vamos aprender a identificar uma progressão geométrica, calcular o n-ésimo termo e também entender como calcular a soma dos termos de uma PG. Além disso, exploraremos as aplicações práticas das progressões geométricas, especialmente em situações financeiras, como no cálculo de juros compostos, investimentos a longo prazo e outros cenários em que os valores aumentam ou diminuem exponencialmente."
        },
        {
          "modulo_id": 4,
          "titulo": "Trigonometria: Seno, Cosseno e Tangente",
          "video": "https://www.youtube.com/watch?v=Jf0sA3wBqXE&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=11",
          "descricao": "A trigonometria é uma parte fundamental da matemática, especialmente para o estudo de triângulos e suas propriedades. Nesta aula, vamos aprender sobre as três funções trigonométricas básicas: seno, cosseno e tangente, focando em como calcular esses valores em triângulos retângulos. Além disso, discutiremos as aplicações práticas da trigonometria em diversas áreas, como na física, na engenharia, na navegação e até em áreas como a arquitetura e a medicina, mostrando a importância dessa área da matemática para a resolução de problemas complexos e a análise de fenômenos do mundo real."
        },
        {
          "modulo_id": 7,
          "titulo": "Cálculo Diferencial: Derivadas e Suas Aplicações",
          "video": "https://www.youtube.com/watch?v=GPTxrh_mhow&list=PLTPg64KdGgYhYpS5nXdFgdqEZDOS5lARB&index=12",
          "descricao": "O cálculo diferencial é uma das áreas mais essenciais da matemática moderna. Nesta aula, vamos aprender o conceito de derivada, que descreve a taxa de variação de uma função em relação a uma variável. Vamos entender como calcular derivadas e explorar como elas são aplicadas na resolução de problemas do mundo real, como otimização de lucros e minimização de custos em empresas, além de sua utilização em modelagem de fenômenos naturais, como a velocidade de partículas e o crescimento populacional. Compreender as derivadas é crucial para quem deseja aprofundar seus estudos em cálculo e em diversas áreas da ciência e da engenharia."
        }
      ]

    });
    // Inserindo dados na tabela `arquivos`
    const arquivos = await prisma.arquivos.createMany({
      data: [
        { aula_id: 1, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 1, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 1, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 2, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 2, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 2, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 3, url: "exemplo/conteudo/exercicios.pdf", tipo: 'conteudo' },
        { aula_id: 3, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 4, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 4, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 5, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 5, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 6, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 6, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 7, url: "exemplo/conteudo/exercicios.pdf", tipo: 'conteudo' },
        { aula_id: 7, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 8, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 8, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 9, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 9, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 10, url: "exemplo/conteudo/exercicios.pdf", tipo: 'conteudo' },
        { aula_id: 10, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 11, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 11, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 12, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 12, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 13, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 13, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 14, url: "exemplo/conteudo/exercicios.pdf", tipo: 'conteudo' },
        { aula_id: 14, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 15, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 15, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 16, url: "exemplo/conteudo/exercicios.pdf", tipo: 'conteudo' },
        { aula_id: 16, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 17, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 17, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 18, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 18, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 19, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 19, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 20, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 20, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 21, url: "exemplo/conteudo/exercicios.pdf", tipo: 'conteudo' },
        { aula_id: 21, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 22, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 22, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 23, url: "exemplo/conteudo/exercicios.pdf", tipo: 'conteudo' },
        { aula_id: 23, url: "exemplo/gabarito/gabarito-simulado.pdf", tipo: 'gabarito' },
        { aula_id: 24, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 24, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 25, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 25, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 26, url: "exemplo/conteudo/exercicios.pdf", tipo: 'conteudo' },
        { aula_id: 26, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 27, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 27, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 28, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 28, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 29, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 29, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 30, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 30, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 31, url: "exemplo/conteudo/exercicios.pdf", tipo: 'conteudo' },
        { aula_id: 31, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 32, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 32, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 33, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 33, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 34, url: "exemplo/conteudo/LISTA DE EXERCÍCIOS.pdf", tipo: 'conteudo' },
        { aula_id: 34, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' },
        { aula_id: 35, url: "exemplo/conteudo/Conjuntos e conjuntos numéricos.pdf", tipo: 'conteudo' },
        { aula_id: 35, url: "exemplo/gabarito/Gabarito-questoes.pdf", tipo: 'gabarito' }
      ],
    });

    const feitos = await prisma.feito.createMany({
      data: [
        { feito: true, revisar: false, aula_id: 1, aluno_id: 1 },
        { feito: false, revisar: true, aula_id: 2, aluno_id: 1 },
        { feito: true, revisar: true, aula_id: 3, aluno_id: 1 },
        { feito: false, revisar: false, aula_id: 4, aluno_id: 1 },
        { feito: true, revisar: true, aula_id: 5, aluno_id: 1 },
        { feito: false, revisar: true, aula_id: 6, aluno_id: 1 },
        { feito: true, revisar: false, aula_id: 7, aluno_id: 2 },
        { feito: false, revisar: false, aula_id: 8, aluno_id: 2 },
        { feito: true, revisar: true, aula_id: 9, aluno_id: 2 },
        { feito: false, revisar: true, aula_id: 10, aluno_id: 2 },
        { feito: true, revisar: true, aula_id: 11, aluno_id: 2 },
        { feito: false, revisar: false, aula_id: 12, aluno_id: 2 },
        { feito: true, revisar: false, aula_id: 1, aluno_id: 3 },
        { feito: false, revisar: true, aula_id: 2, aluno_id: 3 },
        { feito: true, revisar: true, aula_id: 3, aluno_id: 3 },
        { feito: false, revisar: false, aula_id: 4, aluno_id: 3 },
        { feito: true, revisar: true, aula_id: 5, aluno_id: 3 },
        { feito: false, revisar: true, aula_id: 6, aluno_id: 3 },
        { feito: true, revisar: true, aula_id: 7, aluno_id: 4 },
        { feito: false, revisar: false, aula_id: 8, aluno_id: 4 },
        { feito: true, revisar: false, aula_id: 9, aluno_id: 4 },
        { feito: false, revisar: true, aula_id: 10, aluno_id: 4 },
        { feito: true, revisar: true, aula_id: 11, aluno_id: 4 },
        { feito: false, revisar: false, aula_id: 12, aluno_id: 4 },
      ],
    });


    // Inserindo dados na tabela `professor`
    const professores = await prisma.professor.createMany({
      data: [
        { usuario_id: 1, turma_id: 1 },
        { usuario_id: 1, turma_id: 2 },
        { usuario_id: 1, turma_id: 3 },
      ],
    });

    console.log('Banco de dados preenchido com sucesso.');
  } catch (error) {
    console.error('Erro ao popular o banco de dados:', error);
  } finally {
    await prisma.$disconnect();
  }
}

async function main() {
  await clearDatabase();
  await seedDatabase();
}

main().catch(e => {
  console.error(e);
  process.exit(1);
});
