import env from "dotenv";
import ArquivosService from "../services/ArquivosService.js";
import path from "path";
import { sendError, sendResponse } from "../utils/messages.js";
import { ZodError } from 'zod';
import { APIErro } from "../utils/ApiError.js";
import { zodCommon } from "../utils/zodCommonError.js";

env.config();

class ArquivosController {

  static listar = async (req, res) => {
    try {
      const { aula_id } = req.query;

      const parametros = {
        aula_id: aula_id,
      }

      const aulaExist = await ArquivosService.listar(parametros);

      return sendResponse(res, 200, { data: aulaExist });

    } catch (err) {

      if (err instanceof ZodError) {
        return sendError(res, 400, await zodCommon(err));

      } else if (err instanceof APIErro) {
        const { code, errors } = err.toJson();
        return sendError(res, code, ...errors);
      }

      return sendError(res, 500, "Ocorreu um erro interno no servidor!");
    }
  };


  static inserir = async (req, res) => {
    try {
      const { conteudo, gabarito } = req.files;

      if (!conteudo && !gabarito) {
        return sendError(res, 400, ['Nenhum arquivo enviado.']);
      }

      const parametros = {
        aula_id: req.body.aula_id,
      };

      const questaoCreate = await ArquivosService.create(parametros, conteudo, gabarito)

      return sendResponse(res, 201, { data: questaoCreate });

    } catch (err) {
      if (err instanceof ZodError) {
        return sendError(res, 400, await zodCommon(err));

      } else if (err instanceof APIErro) {
        const { code, errors } = err.toJson();
        return sendError(res, code, ...errors);
      }

      return sendError(res, 500, "Ocorreu um erro interno no servidor!");
    }
  }


  static buscar_arquivo = async (req, res) => {
    try {
      const fileName = req.params[0]
      const filePath = path.join(process.cwd(), './uploads/arquivos', fileName);

      res.sendFile(filePath, (err) => {
        if (err) {
          return sendError(res, 404, ['Arquivo não foi encontrado']);
        }
      });

    } catch (err) {
      return sendError(res, 500, "Ocorreu um erro interno no servidor!");
    }
  };

  static deletar = async (req, res) => {
    try {

      const id = { id: req.params.id };

      const arquivoDeletada = await ArquivosService.deletar(id);

      return sendResponse(res, 200, { data: arquivoDeletada });

    } catch (err) {


      if (err instanceof ZodError) {
        return sendError(res, 400, await zodCommon(err));

      } else if (err instanceof APIErro) {
        const { code, errors } = err.toJson();
        return sendError(res, code, ...errors);
      }

      return sendError(res, 500, "Ocorreu um erro interno no servidor!");
    }
  };
}

export default ArquivosController;
