import env from "dotenv";
import { sendError, sendResponse } from "../utils/messages.js";
import moduloService from "../services/moduloService.js";
import { ZodError } from "zod";
import { APIErro } from "../utils/ApiError.js";
import { zodCommon } from "../utils/zodCommonError.js";

env.config()

class ModuloController{
  static listar = async (req, res) => {
    try {
      const { turma_id, titulo, descricao, image } = req.query;
      const filtro = {
        turma_id: turma_id,
        titulo: titulo,
        descricao: descricao,
        image: image
      };
      const response = await moduloService.listar(filtro);

      return sendResponse(res,200, {data: response});

    } catch (err) {

      if (err instanceof ZodError) {
        return sendError(res, 400, await zodCommon(err));

      } else if (err instanceof APIErro) {
        const { code, errors } = err.toJson();
        return sendError(res, code, ...errors);
      }

      return sendError(res, 500, "Ocorreu um erro interno no servidor!");
    }
  };

    static listarPorId = async (req, res) => {
      try {
        const id = { id: req.params.id };
        const response = await moduloService.listarPorId(parseInt(id.id));
       
        return sendResponse(res,200, {data:response});
  
      } catch (err) {

        if (err instanceof ZodError) {
          return sendError(res, 400, await zodCommon(err));
  
        } else if (err instanceof APIErro) {
          const { code, errors } = err.toJson();
          return sendError(res, code, ...errors);
        }
  
        return sendError(res, 500, "Ocorreu um erro interno no servidor!");
      }
    };

  //POST
  static inserir = async (req, res) => {

console.log('Iniciando inserção de módulo...');
console.log('Arquivo recebido:', req.file);


    try {
      const generateRandomNumber = () => Math.floor(Math.random() * 1000) + 1;
      const file = req.file

      if(file){
        file.originalname = `${generateRandomNumber()}_${file.originalname}`
      }

      const { turma_id, titulo, descricao} = req.body;
      const data = {
        turma_id: parseInt(turma_id),    
        titulo: titulo,      
        descricao: descricao,
        image: file ? file.originalname : null
      };
      const imageUrl = `${req.protocol}://${req.get('host')}/imagens/${file.originalname}`;

      const response = await moduloService.inserir(data, file, imageUrl);

      return sendResponse(res,201, {data: response});

    } catch (err) {
      if (err instanceof ZodError) {
        return sendError(res, 400, await zodCommon(err));

      } else if (err instanceof APIErro) {
        const { code, errors } = err.toJson();
        return sendError(res, code, ...errors);
      }

      return sendError(res, 500, "Ocorreu um erro interno no servidor!");
      
    }
  };    

  static deletar = async (req, res) => {
    try {
      const response = await moduloService.deletar(parseInt(req.params.id));
      return sendResponse(res,200, {data:response});

  } catch (err) {
    if (err instanceof ZodError) {
      return sendError(res, 400, await zodCommon(err));

    } else if (err instanceof APIErro) {
      const { code, errors } = err.toJson();
      return sendError(res, code, ...errors);
    }

    return sendError(res, 500, "Ocorreu um erro interno no servidor!");
  
    }
  }

  
  static atualizar = async (req, res) => {
    try {
      const generateRandomNumber = () => Math.floor(Math.random() * 1000) + 1;
      const file = req.file

      if(file){
        file.originalname = `${generateRandomNumber()}_${file.originalname}`
      }

      const id = req.params.id
      const { turma_id, titulo, descricao} = req.body;
      const data = {
        id: parseInt(id),
        turma_id: turma_id ? parseInt(turma_id) : null,    
        titulo: titulo ? titulo : null,      
        descricao: descricao ? descricao : null,
        image: file ? file.originalname : null
      };
      const imageUrl = `${req.protocol}://${req.get('host')}/imagens/${file.originalname}`;

      const response = await moduloService.atualizar(data, file, imageUrl);

      return sendResponse(res,200, {data: response});
    } catch (err) {
      if (err instanceof ZodError) {
        return sendError(res, 400, await zodCommon(err));
  
      } else if (err instanceof APIErro) {
        const { code, errors } = err.toJson();
        return sendError(res, code, ...errors);
      }
  
      return sendError(res, 500, "Ocorreu um erro interno no servidor!");
    }
  }
}

export default ModuloController;