import env from "dotenv";
import turmaService from "../services/turmaService.js"
import { ZodError } from "zod";
import { sendError, sendResponse } from "../utils/messages.js";
import { APIErro } from "../utils/ApiError.js";
import { zodCommon } from "../utils/zodCommonError.js";

env.config();


class TurmaController{
  static listar = async (req, res) => {
    try {
      const { nome } = req.query;
      const filtro = {
        nome: nome
      };
      const response = await turmaService.listar(filtro);

      return sendResponse(res,201, {data: response});

    } catch (err) {
      
      if (err instanceof APIErro) {
        const { code, errors } = err.toJson();
        return sendError(res, code, ...errors);
      }

      return sendError(res, 500, "Ocorreu um erro interno no servidor!");
    }
  };

  static listarPorID = async (req, res) => {
    try {
      const id = { id: req.params.id };
      const response = await turmaService.listarPorId(parseInt(id.id));
     
      return sendResponse(res,201, {data:response});

    } catch (err) {

      if (err instanceof ZodError) {
        return sendError(res, 400, await zodCommon(err));

      } else if (err instanceof APIErro) {
        const { code, errors } = err.toJson();
        return sendError(res, code, ...errors);
      }

      return sendError(res, 500, "Ocorreu um erro interno no servidor!");
    }
   
  };
  static atualizar = async (req, res) => {
    try {
      let id = req.params.id
     
      const { nome } = req.body;
      const data = {
      nome:nome    
      }
    const response = await turmaService.atualizarTurma(parseInt(id),data)
    return sendResponse(res,201, {data:response});

    } catch (err) {

      if (err instanceof ZodError) {
        return sendError(res, 400, await zodCommon(err));

      } else if (err instanceof APIErro) {
        const { code, errors } = err.toJson();
        return sendError(res, code, ...errors);
      }

      return sendError(res, 500, "Ocorreu um erro interno no servidor!");
    }
  }
}
export default TurmaController;
