//routes
import arquivosRoutes from "../routes/arquivos.js";
import authPaths from "../routes/auth.js";
import turmaPaths from "../routes/turma.js"
import moduloRoutes from "../routes/modulo.js";
import usuarioCsvRoutes from "../routes/usuario-csv.js";
import aulaRoutes from "../routes/aula.js";
import usuarioRoutes from "../routes/usuario.js"; 
//schemas
import arquivosSchema from "../schemas/arquivosSchemaDoc.js";
import usuarioCsvSchema from "../schemas/usuario-csvSchemaDoc.js";
import authSchemas from "../schemas/authSchema.js";
import loginSchema from "../schemas/loginSchemaDoc.js"
import turmaSchema from "../schemas/turmaSchema.js";
import aulaSchema from "../schemas/aulaSchemaDoc.js";
import moduloSchema from "../schemas/moduloSchemaDoc.js";
import usuarioSchema from "../schemas/usuarioSchema.js";

// Função para definir as URLs do servidor dependendo do ambiente
const getServersInCorrectOrder = () => {
    const devUrl = { url: process.env.SWAGGER_DEV_URL || "http://localhost:3051" };
    const prodUrl = { url: process.env.SWAGGER_PROD_URL || "http://localhost:3051" };
  

    if (process.env.NODE_ENV === "production") return [prodUrl, devUrl];
    else return [devUrl, prodUrl];
};

// Função para obter as opções do Swagger
const getSwaggerOptions = () => {
    return {
        swaggerDefinition: {
            openapi: "3.0.0",
            info: {
                title: "Plataforma de matemática",
                version: "1.0-alpha",
                description: "Plataforma de matemática\n\nÉ necessário autenticar com token JWT antes de utilizar as rotas, a rota /login deverá ser feita utilizando uma matricula e senha válidas.",
            },
            servers: getServersInCorrectOrder(),
            tags: [
                {
                    name: "Login",
                    description: "Rota para autenticação"
                },
                {
                    name: "Aulas",
                    description: "Rota para gestão de aulas"
                },
                {
                    name: "Módulos",
                    description: "Rota para gestão de módulos"
                },
                {
                    name: "Turmas",
                    description: "Rota para gestão de turmas"
                },
                {
                    name: "Usuários", 
                    description: "Rota para gestão de usuários"
                },
                {
                    name: "Usuários/csv", 
                    description: "Rota para inserir usuários utilizando um arquivo no formato CSV"
                },
                {
                    name: "Arquivos", 
                    description: "Rotas para gestão de Arquivos das aulas."
                },
                
            ],
            paths: {
                ...authPaths,
                ...turmaPaths,
                ...moduloRoutes,
                ...usuarioCsvRoutes,
                ...aulaRoutes,
                ...usuarioRoutes,
                ...arquivosRoutes,
            },
            components: {
                securitySchemes: {
                    bearerAuth: {
                        type: "http",
                        scheme: "bearer",
                        bearerFormat: "JWT"
                    }
                },
                schemas: {
                    ...authSchemas,
                    ...turmaSchema,
                    ...loginSchema,
                    ...moduloSchema,
                    ...usuarioCsvSchema,
                    ...aulaSchema,
                    ...usuarioSchema,
                    ...arquivosSchema,
                }
            },
            security: [{
                bearerAuth: []
            }]
        },
        apis: ["./src/routes/*.js"]
    };
};

export default getSwaggerOptions;