const arquivosRoutes = {
    "/arquivos": {
        get: {
            tags: ["Arquivos"],
            summary: "Lista todos os arquivos de uma aula.",
            security: [{ bearerAuth: [] }],
            parameters: [
                {
                    name: "aula_id",
                    in: "query",
                    description: "id da aula.",
                    required: true,
                    schema: {
                        type: "integer"
                    }
                },
            ],
            responses: {
                "200": {
                    description: "Arquivos das aulas encontrados.",
                    content: {
                        "application/json": {
                            schema: {
                                $ref: "#/components/schemas/getArquivos"
                            }
                        }
                    }
                },
                "400": {
                    description: "Requisição com sintaxe incorreta ou outros problemas.",
                    content: {
                        $ref: "#/components/schemas/erro400arquivo"
                    }                
                },
                "404": {
                    description: "Nenhum arquivo encontrado.",
                    content: {
                        $ref: "#/components/schemas/erro404arquivos"
                    }                
                },
                "500": {
                    description: "Servidor encontrou um erro interno.",
                    content: {
                        $ref: "#/components/schemas/erro500"
                    }                
                },
            }
        },
        post: {
            tags: ["Arquivos"],
            summary: "Salva arquivos de uma aula na API e no Banco de dados.",
            security: [{ bearerAuth: [] }],
            requestBody: {
                content: {
                    "multipart/form-data": {
                        schema: {
                            type: "object",
                            properties: {
                                conteudo: {
                                    type: "string",
                                    format: "binary",
                                    description: "Arquivo pdf com as conteúdo."
                                },
                                gabarito: {
                                    type: "string",
                                    format: "binary",
                                    description: "Arquivo pdf com gabaritos."
                                },
                                aula_id: {
                                    type: "integer",
                                    description: "ID da aula."
                                }
                            },
                            required: ["conteudo", "gabarito", "aula_id"]
                        }
                    }
                },
                required: true
            },
            responses: {
                "201": {
                    description: "Arquivo salvo com sucesso.",
                    content: {
                        "application/json": {
                            schema: {
                                $ref: "#/components/schemas/postArquivos"
                            }
                        }
                    }
                },
                "400": {
                    description: "Houve um erro em algum parâmetro do corpo da requisição.",
                    content: {
                        $ref: "#/components/schemas/erro400arquivo"
                    }                
                },
                "404": {
                    description: "Aula não existe.",
                    content: {
                        $ref: "#/components/schemas/erro404aulanaoExiste"
                    }                
                },
                "500": {
                    description: "Servidor encontrou um erro interno.",
                    content: {
                        $ref: "#/components/schemas/erro500"
                    }                
                },
            }
        }
    },
    "/arquivos/{url}": {  
        get: {
            tags: ["Arquivos"],
            summary: "Retorna um arquivo de uma aula.",
            security: [{ bearerAuth: [] }],
            parameters: [
                {
                    name: "url",
                    in: "path",
                    description: "url do arquivo.",
                    required: true,
                    schema: {
                        type: "string"
                    }
                }
            ],
            responses: {
                "200": {
                    description: "Retorna o PDF encontrado.",
                    content: {
                        "application/json": {
                            schema: {
                                $ref: "#/components/schemas/getPDF"
                            }
                        }
                    }
                },
                "404": {
                    description: "Arquivo não foi encontrado.",
                    content: {
                        $ref: "#/components/schemas/erro404arquivos"
                    }
                },
                "500": {
                    description: "Servidor encontrou um erro interno.",
                    content: {
                        $ref: "#/components/schemas/erro500"
                    }
                }
            }
        },
    },
    "/arquivos/{id}": {
        delete: {
            tags: ["Arquivos"],
            summary: "Deleta um arquivo na API e no banco de dados.",
            security: [{ bearerAuth: [] }],
            parameters: [
                {
                    name: "id",
                    in: "path",
                    description: "ID do arquivo salvo no banco de dados.",
                    required: true,
                    schema: {
                        type: "integer"
                    }
                }
            ],
            responses: {
                "200": {
                    description: "Arquivo deletado com sucesso.",
                    content: {
                        "application/json": {
                            schema: {
                                $ref: "#/components/schemas/deleteArquivoRes"
                            }
                        }
                    }
                },
                "400": {
                    description: "Requisição com sintaxe incorreta ou outros problemas.",
                    content: {
                        $ref: "#/components/schemas/erro400arquivo"
                    }
                },
                "404": {
                    description: "Nenhum arquivo encontrado.",
                    content: {
                        $ref: "#/components/schemas/erro404arquivos"
                    }
                },
                "500": {
                    description: "Servidor encontrou um erro interno.",
                    content: {
                        $ref: "#/components/schemas/erro500"
                    }
                }
            }
        }
    },
};

export default arquivosRoutes;
