import {prisma} from "../configs/prismaClient.js";
import bcrypt from 'bcrypt';

class usuarioRepository {
  
  static async listarUsuarios(filtros, skip, take, order) {
    const where = {
      ...filtros,
      active: filtros.active === 'true' ? true : filtros.active === 'false' ? false : undefined,
    };
    return await prisma.usuario.findMany({
        where,
        skip: skip,
        take: take,
        orderBy: { id: order },
        select: {
            id: true,
            nome: true,
            matricula: true,
            active: true,
        },
    });
  }

  static async buscarUsuarioPorId(id) {
  
    return await prisma.usuario.findUnique({
        where: { id:id },
        select: {
            id: true,
            nome: true,
            matricula: true,
            active: true,
        },
    });
  };

  static async buscarId(id) {
    return await prisma.usuario.findUnique({
        where: { id:id }
    });
  };

  static async atualizarUsuario(filtro) {
    return await prisma.usuario.update(filtro);
  };

  static async buscarGrupoPorId(id) {
    return await prisma.grupo.findUnique({
        where: { id },
        select: {
            id: true,
        },
    });
  };

  static async buscarSenha(id){
    return await prisma.usuario.findUnique({
      where: { id:id },
      select: {
          id: true,
          matricula: true,
          senha:true
      },
    })
  }

  static async buscarUsuarioPorMatricula(matricula) {
    return await prisma.usuario.findFirst({
      where: {
        matricula: matricula
      },
      select: {
        id: true,
        nome: true,
        senha: true,
        matricula: true,
        active: true
      }
    });
  }

  static async criarUsuario(data) {
    data.senha = await bcrypt.hash(data.senha, parseInt(process.env.SALT, 10));
    return await prisma.usuario.create({data});
  }

  static async listar_csv() {
    return await prisma.usuario.findMany({
      select: {
        nome: true,
        matricula: true,
      },
    });
  }

  static async buscar_turmas() {
    return await prisma.turma.findMany();
  }

  static async inserir_alunos(insert) {
    return await prisma.aluno.createMany({
      data: insert,
    });
  }

  static async grupo_alunos() {
    return await prisma.grupo.findFirst({
      where: {
        nome: { contains: "alunos" },
      },
    });
  }

  static async inserir_usuarios(insert) {
    return await prisma.usuario.create({
      data: {
        ...insert,
      },
      select: {
        id: true,
        nome: true,
        matricula: true,
        grupo_id: true,
        active: true,
      },
    });
  }

  static async contarUsuarios() {
    return await prisma.usuario.count();
  }
}

export default usuarioRepository;
