import { sendError } from "../utils/messages.js";
import ArquivosController from "../controllers/ArquivosController.js";
import express from "express"
const router = express.Router();

import AuthMiddleware from "../middlewares/AuthMiddleware.js";
import PermissaoMiddleware from "../middlewares/permissaoMiddleware.js";

import multer from "multer";

const fileFilter = (req, file, cb) => {
  const allowedTypes = [
    'application/pdf', // PDF
    'application/msword', // DOC
    'application/vnd.openxmlformats-officedocument.wordprocessingml.document', // DOCX
  ];

  if (allowedTypes.includes(file.mimetype)) {
    cb(null, true);
  } else {
    cb(new Error('Tipo de arquivo enviado não é suportado. Envie no formato: .PDF, .DOC, .DOCX'));
  }
};

const upload = multer({
  storage: multer.memoryStorage(),
  fileFilter,
  limits: { fileSize: 20 * 1024 * 1024 },
}).fields([
  { name: 'conteudo', maxCount: 10 },
  { name: 'gabarito', maxCount: 10 },
]);


router
router.get("/arquivos", AuthMiddleware, PermissaoMiddleware, ArquivosController.listar)
router.get('/arquivos/*', ArquivosController.buscar_arquivo);
router.post(
  '/arquivos', AuthMiddleware, PermissaoMiddleware,
  upload,
  (err, req, res, next) => {
    if (err.message == "Tipo de arquivo enviado não é suportado. Envie no formato: .PDF, .DOC, .DOCX") {
      return sendError(res, 400, [err.message]);
    }
  },
  ArquivosController.inserir


);

router.delete('/arquivos/:id', AuthMiddleware, PermissaoMiddleware, ArquivosController.deletar)


export default router;