import ArquivosRepository from "../repositories/ArquivosRepository.js";
import ArquivosSchema from "../schemas/ArquivosSchema.js";
import  fs  from "fs";
import path from "path";
import { APIErro } from "../utils/ApiError.js";

class ArquivosService {

    static async listar(parametros) {
        const parametrosValidados = ArquivosSchema.idAulaSchema.parse(parametros);
       
        const arquivos = await ArquivosRepository.BuscarArquivos(parametrosValidados.aula_id);
        if (arquivos.length === 0) {
            return null
        }

        return arquivos;
    }

    static async create(parametros, conteudo, gabarito) {
        const insert = ArquivosSchema.idAulaSchema.parse(parametros);

        const aula = await ArquivosRepository.aulaExists(insert.aula_id);

        if (!aula) {
            throw new APIErro(404, [{ message: "A aula informado não existe.", }])
        }

        let arquivosSalvos = []

        const saveFiles = (files, aula_id, folder) => {
            const folderPath = path.join(process.cwd(), `./uploads/arquivos/${aula_id}/${folder}`);

            if (!fs.existsSync(folderPath)) {
                fs.mkdirSync(folderPath, { recursive: true });
            }

            files.forEach((file) => {
                const filePath = path.join(folderPath, file.originalname);

                fs.writeFileSync(filePath, file.buffer);

                arquivosSalvos.push({
                    url: `${aula_id}/${folder}/${file.originalname}`,
                    aula_id: aula_id,
                    tipo: folder
                });
            });
        };

        if (conteudo) saveFiles(conteudo, aula.id, 'conteudo');
        if (gabarito) saveFiles(gabarito, aula.id, 'gabarito');

        let count = await ArquivosRepository.create(arquivosSalvos)
        
        return `${count > 1? count + " arquivos foram salvos.": count + " arquivo foi salvo."}`
    }

    static async deletar(id) {
        const idValidado = ArquivosSchema.idSchema.parse(id);

        const arquivoExists = await ArquivosRepository.buscarPorId(idValidado.id);

        if (!arquivoExists) {
            throw new APIErro(404, [{ message: "Nenhum arquivo encontrado.", }])
        };

        const arquivoDeletado = await ArquivosRepository.deletarArquivo(arquivoExists.id)
        const arquivoDuplicado = await ArquivosRepository.buscarPorUrl(arquivoExists.aula_id, arquivoExists.url);

        const filePath = path.join(process.cwd(), './uploads/arquivos', arquivoDeletado.url);

        if(arquivoDuplicado.length == 0){
            fs.unlink(filePath, () => {});
        }

        return arquivoDeletado;
    }
}

export default ArquivosService;
