import loginRepository from '../repositories/loginRepository.js';
import bcrypt from 'bcryptjs';
import LoginSchema from "../schemas/LoginShema.js"
import {z} from "zod";
import jwt from 'jsonwebtoken';
import dotenv from 'dotenv';
import 'dotenv/config'
import { APIErro } from '../utils/ApiError.js';


dotenv.config();

class loginService {

  static async login(login){
   
    const {matricula, senha} = LoginSchema.login.parse(login);
    const JWT = process.env.PRIVATE_KEY;

    const flitros = {
        where: {
            matricula: matricula,
        }
    }
    const usuario = await loginRepository.login(flitros);

    if(!usuario){ 
        throw new z.ZodError([{
            path: ["usuario"],
            message:"Usuario não exite na base de dados verifique se a matricula esta correto!",
            code: z.ZodIssueCode.custom,
            params: {
                status: 401, // Adicionando um detalhe personalizado
              },
        }]);  
    };
    const senhaValida = await bcrypt.compare(senha, usuario.senha);
    if(!senhaValida){
        throw new z.ZodError([{
            path: ["usuario"],
            message:"Senha informada esta incorreta!",
            code: z.ZodIssueCode.custom,
            params: {
                status: 401, // Adicionando um detalhe personalizado
              },
        }]);  
    }

    const jwtConfigAccesses = {  expiresIn: '1d',    algorithm: 'HS256', };
    const jwtConfigRefrash = {  expiresIn: '40m',    algorithm: 'HS256', };

    let tokenValido = false;
    let refresh_token = null

    try {
        jwt.verify(usuario.refresh_token, JWT)
        tokenValido = true;
    } catch (error) {}

    if(tokenValido){
      refresh_token = usuario.refresh_token
    }else{
      refresh_token = jwt.sign({ data: {'_id': usuario.id} }, JWT, jwtConfigRefrash);

      const filtro = {
        where: { id: usuario.id },
        data: {
          nome: usuario.nome,
          matricula: usuario.matricula,
          active: usuario.active,
          senha: usuario.senha,
          grupo_id: usuario.grupo_id,
          refresh_token: refresh_token
        },
        select: {
          id: true,
          nome: true,
          matricula: true,
          active: true,
          grupo_id: true,
        },
      }
      await loginRepository.salvarToken(filtro)
    }

    const access_token = jwt.sign({ data: {'_id': usuario.id} }, JWT, jwtConfigAccesses);

    const filtro_permissoes = {
        where: {
          permissoes: {
            some: {
              grupo_id: usuario.grupo_id,
            },
          },
        },
      }
    let permissoes = await loginRepository.permissoes(filtro_permissoes)

    delete usuario.senha
    delete usuario.refresh_token
    return { 
        data:{
            refresh_token: refresh_token,
            access_token: access_token,
            usuario: usuario, 
            permissoes
        }
    }
  }

  static async logout(logout){
   
    const { id } = LoginSchema.logout.parse(logout);

    const usuario = await loginRepository.buscarUsuarioPorId(id);

    const filtro = {
      where: { id: id },
      data: {
        nome: usuario.nome,
        matricula: usuario.matricula,
        active: usuario.active,
        senha: usuario.senha,
        grupo_id: usuario.grupo_id,
        refresh_token: null
      },
      select: {
        id: true,
        nome: true,
        matricula: true,
        active: true,
        grupo_id: true,
      },
    }
    await loginRepository.salvarToken(filtro)
    delete usuario.senha
    delete usuario.refresh_token
    return { 
        data:{
            usuario: usuario, 
        }
    }
  }

  static async token(login){
   
    const {refresh_token} = LoginSchema.token.parse(login);
    const JWT = process.env.PRIVATE_KEY;

    const decoded = jwt.verify(refresh_token, JWT);
    const id = decoded.data._id;

    const usuario = await loginRepository.buscarUsuarioPorId(id)

    if(!usuario){ 
        throw new z.ZodError([{
            path: ["usuario"],
            message:"Usuario não exite na base de dados verifique se a matricula esta correto!",
            code: z.ZodIssueCode.custom,
            params: {
                status: 401, // Adicionando um detalhe personalizado
              },
        }]);  
    };

    const jwtConfigAccesses = {  expiresIn: '1d',    algorithm: 'HS256', };

    if(refresh_token == usuario.refresh_token){

      const access_token = jwt.sign({ data: {'_id': usuario.id} }, JWT, jwtConfigAccesses);

      const filtro = {
        where: { id: usuario.id },
        data: {
          nome: usuario.nome,
          matricula: usuario.matricula,
          active: usuario.active,
          senha: usuario.senha,
          grupo_id: usuario.grupo_id,
          refresh_token: refresh_token
        },
        select: {
          id: true,
          nome: true,
          matricula: true,
          active: true,
          grupo_id: true,
        },
      }
      await loginRepository.salvarToken(filtro)

      delete usuario.senha
      delete usuario.refresh_token
      return { 
          data:{
              access_token: access_token,
              usuario: usuario
          }
      }

    }else{
      throw new APIErro(498, [{ message: "Token inválido ou expirado ", }])
    }


  }
}

export default loginService;
