import request from "supertest";
import { describe, expect, it} from '@jest/globals';
import app from '../../app.js'
import path from "path";
import fs from "fs";

let token = null
let arquivo2 = null
let arquivo1 = null


describe.skip('Autenticação', () => {
    it("1-Deve chamar a rota de autenticação e pegar o token", async () => {
        const req = await request(app)
        .post('/login')
        .set("Accept", "aplication/json")
        .send({
            matricula:"12345",
            senha:"senhatest"
        })
        token = req.body.data.token
    })
});


describe.skip('GET /arquivos/* - busca arquivos.', () => {

    it('1- Deve retornar o pdf informado na requisição.', async () => {

        const res = await request(app)
            .get('/arquivos/exemplo/conteudo/exercicios.pdf')
            .set("Accept", "application/json")
            .set("Authorization", `Bearer ${token}`)

        expect(res.status).toBe(200);
        expect(res.headers['content-type']).toBe('application/pdf');
        expect(Buffer.isBuffer(res.body)).toBe(true);
        expect(res.body.length).toBeGreaterThan(0);

    })

    it('2- Gera erro se o pdf não existir.', async () => {

        const res = await request(app)
            .get('/arquivos/arquivo/naoexiste.pdf')
            .set("Accept", "application/json")
            .set("Authorization", `Bearer ${token}`)

        
        expect(res.body.error).toEqual(true)
        expect(res.status).toBe(404)
        expect(res.body.message).toEqual("O recurso solicitado não foi encontrado no servidor.")
    })
})

describe.skip('GET /arquivos - busca os arquivos de uma aula.', () => {

    it('1- Deve retornar todos os arquivos de uma aula.', async () => {

        const res = await request(app)
            .get('/arquivos')
            .set("Accept", "application/json")
            .set("Authorization", `Bearer ${token}`)
            .query({aula_id: 2})

        arquivo1 = res.body.data[0].id
        arquivo2 = res.body.data[1].id

        expect(res.body.error).toBe(false);
        expect(res.status).toBe(200);
        expect(res.body.message).toBe("Requisição bem sucedida.");
    });

    it('2- Deve retornar erro 400 quando o aula_id não for number', async () => {

        const res = await request(app)
            .get('/arquivos')
            .set("Accept", "application/json")
            .set("Authorization", `Bearer ${token}`)
            .query({aula_id: "texto"})

        expect(res.body.error).toBe(true);
        expect(res.status).toBe(400);
        expect(res.body.message).toBe("Requisição com sintaxe incorreta ou outros problemas.");
    })
})


