import request from 'supertest';
import app from '../../app';
import UsuarioService from '../../services/usuarioService';
import { ZodError } from "zod";
import { APIErro } from "../../utils/ApiError";
import { zodCommon } from "../../utils/zodCommonError";
import systemUsuarioController from '../../controllers/UsuarioController';

jest.mock('../../services/usuarioService');
jest.mock("../../utils/zodCommonError");

describe.skip('Usuario Controller - listar', () => {
  describe('GET /usuarios', () => {
    it('Deve retornar 200 e a lista de usuários', async () => {
      const mockUsuarios = [{ id: 1, nome: 'Usuario 1' }, { id: 2, nome: 'Usuario 2' }];
      UsuarioService.listarUsuarios.mockResolvedValue(mockUsuarios);

      const response = await request(app).get('/usuario');

      expect(UsuarioService.listarUsuarios).toHaveBeenCalled();
      expect(response.status).toBe(200);
      expect(response.body.data).toEqual(mockUsuarios);
    });

    it('Deve retornar 400 para erros de validação Zod', async () => {
      const mockError = new ZodError([]);
      UsuarioService.listarUsuarios.mockRejectedValue(mockError);

      const response = await request(app).get('/usuario');

      expect(UsuarioService.listarUsuarios).toHaveBeenCalled();
      expect(response.status).toBe(400);
      expect(response.body.error).toBeDefined();
    });

    it('Deve retornar 500 para erros desconhecidos', async () => {
      UsuarioService.listarUsuarios.mockRejectedValue(new Error('Erro desconhecido'));

      const response = await request(app).get('/usuario');

      expect(UsuarioService.listarUsuarios).toHaveBeenCalled();
      expect(response.status).toBe(500);
      expect(response.body.message).toBe('Servidor encontrou um erro interno.');
    });

    it('Deve retornar 400 para erros de APIErro', async () => {
      const mockError = new APIErro(400, [{ message: 'Erro de API' }]);
      UsuarioService.listarUsuarios.mockRejectedValue(mockError);

      const response = await request(app).get('/usuario');

      expect(UsuarioService.listarUsuarios).toHaveBeenCalled();
      expect(response.status).toBe(400);
      expect(response.body.error).toBeDefined();
    });
  });
  describe.skip('Usuario Controller - inserir_csv', () => {
    describe('POST /usuario/csv', () => {
      it('Deve retornar erro 400 quando ocorre um ZodError', async () => {
        const mockZodError = new ZodError([]);
        UsuarioService.inserir_csv.mockRejectedValue(mockZodError);
        zodCommon.mockResolvedValue(["Erro de validação"]);
  
        const response = await request(app)
          .post('/usuario/csv')
          .attach('file-csv', Buffer.from('test'), 'test.csv');
  
        expect(UsuarioService.inserir_csv).toHaveBeenCalled();
        expect(zodCommon).toHaveBeenCalledWith(mockZodError);
        expect(response.status).toBe(400);
        expect(response.body.error).toBe(true);
        expect(response.body.message).toBe("Requisição com sintaxe incorreta ou outros problemas.");
      });
    });
  });
});