import path from "path";
import fs from "fs";
import request from 'supertest';
import { sendError } from "../../utils/messages.js";
import app from '../../app'; // Certifique-se de ajustar o caminho para o seu arquivo de aplicação
import ArquivosService from "../../services/ArquivosService.js";
import ArquivosController from "../../controllers/ArquivosController.js";
jest.mock("../../services/ArquivosService.js");


jest.mock

let token = null

describe('Autenticação', () => {
    it("1-Deve chamar a rota de autenticação e pegar o token", async () => {
        const req = await request(app)
            .post('/login')
            .set("Accept", "aplication/json")
            .send({
                matricula: "12345",
                senha: "senhatest"
            })
        token = req.body.data.token
    })
});

describe('Usuario Controller', () => {
    describe('GET /usuarios', () => {
        describe("500", () => {
            it("Dever retornar o erro 500 ao listar arquivos", async () => {
                ArquivosService.listar.mockRejectedValue(new Error('Erro desconhecido'));

                const response = await request(app)
                    .get('/arquivos')
                    .set("Accept", "application/json")
                    .set("Authorization", `Bearer ${token}`)
                    .query({ aula_id: 2 })

                expect(response.status).toBe(500);
                expect(response.body.data).toBeDefined();
                expect(response.body.message).toBeDefined();
                expect(response.body.error).toEqual(true);

            });
        });
    });
    describe('Post /arquivos', () => {
        describe("500", () => {
            const filePath = path.resolve(process.cwd(), './src/test/arquivos/pdf.pdf');

            it.skip("Dever retornar o erro 500 ao salvar arquivos", async () => {
                ArquivosService.create.mockRejectedValue(new Error('Erro desconhecido'));

                fs.promises.access(filePath)
                const response = await request(app)
                    .post('/arquivos')
                    .set("Accept", "application/json")
                    .set("Authorization", `Bearer ${token}`)
                    .field('aula_id', 2)
                    .attach('conteudo', filePath)
                    .attach('gabarito', filePath)

                expect(response.status).toBe(500);
                expect(response.body.data).toBeDefined();
                expect(response.body.message).toBeDefined();
                expect(response.body.error).toEqual(true);

            });
        });
    });
    describe('POST /usuarios', () => {
        it('Deve retornar erro 500 para erros desconhecidos', async () => {
            ArquivosService.deletar.mockRejectedValue(new Error('Ocorreu um erro interno no servidor!'));

            const response = await request(app)
                .delete('/arquivos/2')
                .set("Accept", "application/json")
                .set("Authorization", `Bearer ${token}`);

            expect(response.body.data).toBeDefined();
            expect(response.body.error).toBeDefined();
            expect(response.body.code).toBeDefined();
            expect(response.body.message).toBeDefined();
            expect(response.body.errors).toBeDefined();
        });
    });
    describe('ArquivoController buscar_arquivo', () => {
        let req, res;

        beforeEach(() => {
            req = {}; // Mock do objeto req
            res = {
                status: jest.fn().mockReturnThis(), // Permite encadeamento com res.json()
                json: jest.fn(), // Mock do método json
            };
            jest.clearAllMocks();
        });

        test('Deve retornar erro 500 se ocorrer um erro desconhecido', async () => {
            await ArquivosController.buscar_arquivo(req, res);

        });
    });

});


