import request from 'supertest';
import app from '../../app';
import AulaService from '../../services/AulaService';
import { ZodError } from 'zod';

jest.mock('../../services/AulaService', () => ({
  create: jest.fn(),
}));

describe.skip('POST /aula (Erro 400 de validação Zod)', () => {
  it('deve retornar erro 400 quando os dados são inválidos', async () => {
    const dadosInvalidos = {
      modulo_id: '1',
      titulo: 123,   // Erro esperado aqui
      video: 'invalid-url', // Outra validação que pode ser gerada
    };

    AulaService.create.mockImplementation(() => {
      throw new ZodError([
        { message: 'modulo_id é obrigatório', path: ['modulo_id'] },
        { message: 'titulo deve ser uma string', path: ['titulo'] },
      ]);
    });

    const response = await request(app)
      .post('/aula')
      .send(dadosInvalidos);


    expect(response.status).toBe(400);
    const formattedErrors = response.body.errors.map(err => `${err.path} - ${err.message}`);
    expect(formattedErrors).toEqual(
        expect.arrayContaining([
          'modulo_id - modulo_id é obrigatório',
          'titulo - titulo deve ser uma string'
        ])
      );   
});
});
