import AuthMiddleware from '../../middlewares/AuthMiddleware.js';
import { sendError } from '../../utils/messages.js';
import jwt from 'jsonwebtoken';
import dotenv from 'dotenv';
import 'dotenv/config';
import { jest } from '@jest/globals';

dotenv.config();

jest.mock('jsonwebtoken');
jest.mock('../../utils/messages.js');

describe('AuthMiddleware', () => {
    let req, res, next;

    beforeEach(() => {
        req = {
            headers: {}
        };
        res = {
            status: jest.fn().mockReturnThis(),
            json: jest.fn()
        };
        next = jest.fn();
    });

    it('should call next if token is valid', () => {
        req.headers['authorization'] = 'Bearer validToken';
        jwt.verify.mockReturnValue({ userId: '123' });

        AuthMiddleware(req, res, next);

        expect(next).toHaveBeenCalled();
    });

    it('should return 401 if no authorization header is present', () => {
        AuthMiddleware(req, res, next);

        expect(sendError).toHaveBeenCalledWith(res, 401, { mensage: "Impossível continuar, usuário sem credenciais" });
    });



    it('should return 500 if there is an internal server error', () => {
        req.headers['authorization'] = 'Bearer validToken';
        jwt.verify.mockImplementation(() => { throw new Error('Internal server error'); });

        AuthMiddleware(req, res, next);

        expect(sendError).toHaveBeenCalledWith(res, 500, [{ mensage: "Erro interno do servidor, tente novamente mais tarde!" }]);
    });
});