import request from 'supertest';
import express from 'express';
import routes from '../../routes/index';

describe.skip("Testando as rotas da aplicação", () => {
  let app;

  beforeAll(() => {
    app = express();
    routes(app);
  });

  it("deve retornar a documentação Swagger na rota '/'", async () => {
    const res = await request(app).get('/');
    expect(res.status).toBe(200);
    expect(res.text).toContain("Swagger UI");
  });

  it("deve retornar 404 para uma rota não existente", async () => {
    const res = await request(app).get('/rota-inexistente');
    expect(res.status).toBe(404);
    expect(res.body.message).toBe("Rota não encontrada");
  });

  it("deve retornar 301 para a rota '/imagens'", async () => {
    const res = await request(app).get('/imagens');
    expect(res.status).toBe(301);
  });

  it("deve retornar 200 para a rota de login", async () => {
    const res = await request(app).post('/login').send({
      matricula: '12345',
      senha: 'senha123'
    });
    expect(res.status).toBe(401);
  });

  it("deve retornar 201 para a rota de turma", async () => {
    const res = await request(app).get('/turma');
    expect(res.status).toBe(201);
  });

  it("deve retornar 200 para a rota de aula", async () => {
    const res = await request(app).get('/aula/1');
    expect(res.status).toBe(401);
  });

  it("deve retornar 200 para a rota de usuário", async () => {
    const res = await request(app).get('/usuario');
    expect(res.status).toBe(200);
  });

  it("deve retornar 200 para a rota de módulo", async () => {
    const res = await request(app).get('/modulo');
    expect(res.status).toBe(200);
  });

  it("deve retornar 401 para a rota '/login' com dados inválidos", async () => {
    const res = await request(app).post('/login').send({
      matricula: '',
      senha: ''
    });
    expect(res.status).toBe(401);
  });

});
