import path from "path";
import request from 'supertest';
import app from '../../app';
import express from 'express';
import moduloService from "../../services/moduloService.js";
import { ZodError } from 'zod';
import faker from 'faker-br';


jest.mock('../../services/moduloService.js', () => ({
  listar: jest.fn().mockRejectedValue(),
  atualizar: jest.fn().mockRejectedValue(),
  deletar: jest.fn().mockRejectedValue(),
  listarPorId: jest.fn().mockRejectedValue(),
  inserir: jest.fn().mockRejectedValue(),
}));

jest.mock('../../middlewares/AuthMiddleware', () => (req, res, next) => {
  req.user = { id: 1 };  // Simula um usuário autenticado
  next();
});



let token = null


describe.skip('modulo Controller',  () => {
    describe('GET /modulo',  () => {
        describe("500",()=>{
            it("Dever retornar o erro 500 ao listar modulo",async ()=> {
                moduloService.listar.mockRejectedValue(new Error('Erro desconhecido'));

                const response = await request(app).get('/modulo')

                expect(moduloService.listar).toHaveBeenCalled();
                expect(response.status).toBe(500);
                expect(response.body.data).toBeDefined();
                expect(response.body.message).toBeDefined();
                expect(response.body.error).toEqual(true);

            });
        });
    });
    
        
describe.skip('modulo Controller',  () => {
    describe("500",()=>{
        it("Dever retornar o erro 500 ao tentar deletar um modulo",async ()=> {
            moduloService.deletar.mockRejectedValue(new Error('Erro desconhecido'));

            const response = await request(app)
            .delete('/modulo/1')


            expect(moduloService.deletar).toHaveBeenCalled();
            expect(response.status).toBe(500);
            expect(response.body.data).toBeDefined();
            expect(response.body.message).toBeDefined();
            expect(response.body.error).toEqual(true);

        });
    });
    describe('modulo Controller', () => {
      describe('GET /modulo/:id', () => {
        describe("500", () => {
          it("Dever retornar o erro 500 ao listar modulo por id", async () => {
            moduloService.listarPorId.mockRejectedValue(new Error('Erro desconhecido'));

            const response = await request(app).get('/modulo/1');

            expect(moduloService.listarPorId).toHaveBeenCalledWith(1);
            expect(response.status).toBe(500);
            expect(response.body.data).toBeDefined();
            expect(response.body.message).toBeDefined();
            expect(response.body.error).toEqual(true);
          });
        });
      describe('modulo Controller', () => {
        describe('PATCH /modulo/:id', () => {
          describe("500", () => {
it("Dever retornar o erro 500 ao tentar atualizar um modulo", async () => {
  moduloService.atualizar = jest.fn().mockRejectedValue(new Error('Erro desconhecido'));
  
  const response = await request(app)
    .patch('/modulo/1')
    .send({
      titulo: "Novo Título",
      descricao: "Nova Descrição"
    });


  expect(response.status).toBe(500);
  expect(response.body.error).toEqual(true);
  expect(response.body.message).toBeDefined();
});


});
});
});
});
});

it("Deve retornar erro 500 ao capturar uma exceção desconhecida", async () => {
  moduloService.inserir.mockImplementation(() => {
    throw new Error('Erro desconhecido');
  });

  const response = await request(app)
    .post('/modulo')
    .set('Authorization', 'Bearer token-valido')
    .send({
      turma_id: 1,
      titulo: "Título",
      descricao: "Descrição"
    });

  expect(response.status).toBe(500);
  expect(response.body.error).toEqual(true);
  
  expect(response.body.message).toBe("Servidor encontrou um erro interno.");
});
});
it('Deve retornar erro 500 para erros desconhecidos', async () => {
  moduloService.inserir.mockRejectedValue(new Error('Ocorreu um erro interno no servidor!'));

  const response = await request(app)
      .post('/modulo')
      .set("Accept", "application/json")
      .set("Authorization", `Bearer ${token}`);

  expect(response.body.error).toBe(true);
  expect(response.body.code).toBe(500);
  expect(response.body.message).toBeDefined();

  expect(response.body).toHaveProperty('message');
  expect(response.body.message).toBe('Servidor encontrou um erro interno.');
});

  });
  


