import turmaRepository from '../../repositories/turmaRepository'; // Ajuste o caminho conforme sua estrutura
import { prisma } from '../../configs/prismaClient';  // Certifique-se de que o caminho está correto

// Mock do Prisma
jest.mock('../../configs/prismaClient', () => ({
  prisma: {
    turma: {
      findMany: jest.fn(),
      findUnique: jest.fn(),
      update: jest.fn(),
    },
  },
}));

describe('turmaRepository', () => {
  beforeEach(() => {
    jest.clearAllMocks();  // Limpa os mocks antes de cada teste
  });

  test('listar', async () => {
    const mockTurmas = [{ id: 1, nome: 'Turma 1' }];
    prisma.turma.findMany.mockResolvedValue(mockTurmas);

    const result = await turmaRepository.listar({});
    expect(result).toEqual(mockTurmas);
    expect(prisma.turma.findMany).toHaveBeenCalledTimes(1);
  });

  test('listarPorId', async () => {
    const mockTurma = { id: 1, nome: 'Turma 1' };
    prisma.turma.findUnique.mockResolvedValue(mockTurma);

    const result = await turmaRepository.listarPorId({ where: { id: 1 } });
    expect(result).toEqual(mockTurma);
    expect(prisma.turma.findUnique).toHaveBeenCalledWith({
      where: { id: 1 },
    });
  });

  test('atualizar', async () => {
    const mockTurmaAtualizada = { id: 1, nome: 'Turma Atualizada' };
    const dataAtualizacao = {
      where: { id: 1 },
      data: { nome: 'Turma Atualizada' },
    };
    prisma.turma.update.mockResolvedValue(mockTurmaAtualizada);

    const result = await turmaRepository.atualizar(dataAtualizacao);
    expect(result).toEqual(mockTurmaAtualizada);
    expect(prisma.turma.update).toHaveBeenCalledWith(dataAtualizacao);
  });

  test('constructFilters', () => {
    const parametros = { id: 1, nome: 'Turma 1', aluno_id: 123, professor_id: 456 };
    const filtroEsperado = {
      where: {
        id: 1,
        nome: { contains: 'Turma 1' },
        aluno: { some: { id: 123 } },
        professor: { some: { id: 456 } },
      },
      select: {
        id: true,
        nome: true,
      },
    };
    const filtro = turmaRepository.constructFilters(parametros);
    expect(filtro).toEqual(filtroEsperado);
  });
});
