import { z } from 'zod';
import TurmaSchema from '../../schemas/turmaSchemas.js';

describe('Testando o schema TurmaSchema', () => {

  it('deve validar corretamente o schema listarPoIdSchema', () => {
    const validData = { id: 123 };
    const result = TurmaSchema.listarPoIdSchema.safeParse(validData);
    expect(result.success).toBe(true);

    const invalidData = { id: 'abc' };  
    const resultInvalid = TurmaSchema.listarPoIdSchema.safeParse(invalidData);
    expect(resultInvalid.success).toBe(false);
    expect(resultInvalid.error.errors[0].message).toBe('Id informado não é do tipo number.');

    const negativeIdData = { id: -123 };  
    const resultNegativeId = TurmaSchema.listarPoIdSchema.safeParse(negativeIdData);
    expect(resultNegativeId.success).toBe(false);
    expect(resultNegativeId.error.errors[0].message).toBe('Id informado não é positivo.');
  });

  it('deve validar corretamente o schema listarSchema', () => {
    const validData = { id: 123, nome: 'Turma 1' };
    const result = TurmaSchema.listarSchema.safeParse(validData);
    expect(result.success).toBe(true);

    const validDataWithOnlyName = { nome: 'Turma 1' };
    const resultOnlyName = TurmaSchema.listarSchema.safeParse(validDataWithOnlyName);
    expect(resultOnlyName.success).toBe(true);

    const invalidData = { id: 'abc', nome: 'Turma 1' }; 
    const resultInvalid = TurmaSchema.listarSchema.safeParse(invalidData);
    expect(resultInvalid.success).toBe(false);
    expect(resultInvalid.error.errors[0].message).toBe('Id informado não é do tipo number.');
  });

  it('deve validar corretamente o schema atualizarSchema', () => {
    const validData = { id: 123, nome: 'Turma Atualizada' };
    const result = TurmaSchema.atualizarSchema.safeParse(validData);
    expect(result.success).toBe(true);

    const validDataWithOnlyName = { nome: 'Turma Atualizada' };
    const resultOnlyName = TurmaSchema.atualizarSchema.safeParse(validDataWithOnlyName);
    expect(resultOnlyName.success).toBe(true);

    const invalidData = { id: 'abc', nome: 'Turma Atualizada' };  
    const resultInvalid = TurmaSchema.atualizarSchema.safeParse(invalidData);
    expect(resultInvalid.success).toBe(false);
    expect(resultInvalid.error.errors[0].message).toBe('Id informado não é do tipo number.');

    const negativeIdData = { id: -123, nome: 'Turma Atualizada' };  
    const resultNegativeId = TurmaSchema.atualizarSchema.safeParse(negativeIdData);
    expect(resultNegativeId.success).toBe(false);
    expect(resultNegativeId.error.errors[0].message).toBe('Id informado não é positivo.');
  });

});
